@@ -13,6 +13,7 @@ import os
 import s3fs
 from typing import Dict
 import toolkit_w
+from toolkit_w.internal import UserToken
 from toolkit_w.internal.api_requestor import APIRequestor
 from toolkit_w.internal.errors import APIError
 from toolkit_w.internal.whatify_response import WhatifyResponse
@@ -65,7 +66,9 @@ class UserManagement(APIResource):
         try:
             response = requestor.post(url, body={'username': email, 'password': password, 'tnc': None}, api_key="")
             toolkit_w.token = response['token']
-            logging.info(' '.join(['user mail:', str(email), '- Login successful']))
+            my_token = UserToken(toolkit_w.token)
+            logging.info(' '.join(['user mail:', str(email), '- Login successful, User ID: ',
+                                   str(my_token.get_user_id()), ' Account ID: ' + str(my_token.get_account_id())]))
         except Exception as ex:
             logging.warning(' '.join(['user mail:', str(email), '- Login FAILED']))
             raise ex
@@ -91,7 +94,8 @@ class UserManagement(APIResource):
         try:
             response = requester.post(url, api_key=admin_token)
             toolkit_w.token = response['result']
-            logging.info(' '.join(['user ID:', str(user_id), '- Login successful']))
+            my_token = UserToken(toolkit_w.token)
+            logging.info(' '.join(['user ID:', str(user_id), '- Login successful with Account ID: ' + str(my_token.get_account_id())]))
         except Exception as ex:
             logging.warning(' '.join(['user ID:', str(user_id), '- Login Failed']))
             raise ex
