@@ -452,6 +452,13 @@ class MyWhatify:
 
     @classmethod
     def get_pipeline_estimators_list(cls, dataset_id, is_pipeline=True, interpt_level=Interpt.PRECISE):
+        """
+        getting the Dataset pipeline or estimators list for dataset_id
+        :param dataset_id:
+        :param is_pipeline:
+        :param interpt_level:
+        :return:
+        """
         with allure.step('getting the Dataset pipeline or estimators list for dataset_id: ' + str(dataset_id)
                      + ' is_pipeline: ' + str(is_pipeline) + ' interpt_level: ' + str(interpt_level)):
             ret_list = None
@@ -463,11 +470,23 @@ class MyWhatify:
 
     @classmethod
     def get_prediction_list(cls, len=10, search_term=None):
+        """
+        get prediction list by search term
+        :param len: len of the return prediction list
+        :param search_term: search term to filter the prediction list
+        :return:
+        """
         with allure.step('getting the prediction list for the prediction_name: ' + str(search_term)):
             return my_toolkit.Prediction.list(search_term=search_term)['hits'][0:len]
 
     @classmethod
     def get_prediction(cls, predict_id, len=None):
+        """
+        get prediction list for predict ID
+        :param predict_id: prediction ID
+        :param len: len of the return prediction list (None for all)
+        :return:
+        """
         with allure.step('getting prediction list for predict_id: ' + str(predict_id) + ' len: ' + str(len)):
             ret_prediction = None
             predict_results = my_toolkit.Prediction.get(predict_id)
@@ -482,7 +501,12 @@ class MyWhatify:
 
     @classmethod
     def get_prediction_error(cls, predict_id):
-        with allure.step('getting prediction list for predict_id: ' + str(predict_id) + ' len: ' + str(len)):
+        """
+        get error for prediction ID
+        :param predict_id:prediction ID
+        :return: error message for predict ID
+        """
+        with allure.step('getting prediction error for predict_id: ' + str(predict_id)):
             error_message = None
             predict_results = my_toolkit.Prediction.get(predict_id)
             error_message = predict_results['error_message']
@@ -490,12 +514,22 @@ class MyWhatify:
 
     @classmethod
     def get_metadata_datasource(cls, data_id):
+        """
+        get_metadata for given datasource ID
+        :param data_id: datasource ID
+        :return: mapping of metadata
+        """
         with allure.step('getting metadata for data id: ' + str(data_id)):
             metadata_results = my_toolkit.Datasource.get_metadata(data_id)
         return metadata_results
 
     @classmethod
     def get_metadata_dataset(cls, data_id):
+        """
+        get_metadata for given dataset ID
+        :param data_id: dataset ID
+        :return: mapping of metadata
+        """
         with allure.step('getting metadata for data id: ' + str(data_id)):
             metadata_results = my_toolkit.Dataset.get_metadata(data_id)
         return metadata_results
@@ -527,7 +561,7 @@ class MyWhatify:
     @classmethod
     def update_wisdom(cls, wisdom_id: int, wisdom_data: str, user_token: str = None):
         """
-        update wisdom
+        update wisdom with given wisdom data
 
         :param wisdom_id (int): the id of the wisdom we want to change
         :param wisdom_data (str): the content we want to change in the wisdom
@@ -543,9 +577,9 @@ class MyWhatify:
     def copy_wisdom(cls, base_wisdom_id: int, target_wisdom_id: int, user_token: str = None):
         """
         copy from base_wisdom_id to target_wisdom_id
-        :param base_wisdom_id:
-        :param target_wisdom_id:
-        :param user_token:
+        :param base_wisdom_id: base wisdom id to copy from
+        :param target_wisdom_id: target wisdom id to change
+        :param user_token: Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
         """
         with allure.step(' '.join(['copying wisdom ID:', str(base_wisdom_id), 'to wisdom ID:', str(target_wisdom_id)])):
             logging.info(' '.join(['Copying wisdom date from wisdom ID:', str(base_wisdom_id), 'to wisdom ID:', str(target_wisdom_id)]))
@@ -556,7 +590,7 @@ class MyWhatify:
     @classmethod
     def delete_wisdom(cls, wisdom_id: int, user_token: str = None):
         """
-        delete wisdom
+        delete wisdom by given wisdom ID
 
         :param wisdom_id (int): the wisdom ID to delete
         :param user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
@@ -578,6 +612,17 @@ class MyWhatify:
             my_list = my_toolkit.Wisdom.get_wisdom_list_with_demo(search_term=search_term)
         return my_list
 
+    @classmethod
+    def get_suggest_wisdom_list(cls, search_term: str = None):
+        """
+        get suggest wisdom list for current user
+        :return:
+        suggest wisdom list
+        """
+        with allure.step('getting suggest wisdom list with search term: ' + str(search_term)):
+            my_list = my_toolkit.Wisdom.get_suggest_wisdom_list(search_term=search_term)
+        return my_list
+
     @classmethod
     def get_wisdom(cls, wisdom_id: int):
         """
